check property
CheckFunc<T> ?
check
final
Function to verify items when adding to a repeated field.
Only available in repeated fields.
Implementation
final CheckFunc<T>? check;
Function to verify items when adding to a repeated field.
Only available in repeated fields.
final CheckFunc<T>? check;