Locale class

Based on the supported Geocoding locale directory names found in the resources/geocoding directory.

Locale metadata is also based on CLDR version 44.1 from https://github.dev/unicode-org/cldr-json/blob/main/cldr-json/cldr-localenames-modern

Constructors

Locale({required String language, required String country})
const

Properties

country → String
final
hashCode → int
The hash code for this object.
no setterinherited
language → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDisplayCountry(Locale locale) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

candata → Locale
no setter
candataFrench → Locale
no setter
china → Locale
no setter
chinese → Locale
no setter
english → Locale
no setter
france → Locale
no setter
french → Locale
no setter
german → Locale
no setter
germany → Locale
no setter
italian → Locale
no setter
italy → Locale
no setter
japan → Locale
no setter
japanese → Locale
no setter
korea → Locale
no setter
korean → Locale
no setter
prc → Locale
no setter
simplifiedChinese → Locale
no setter
taiwan → Locale
no setter
traditionalChinese → Locale
no setter
uk → Locale
no setter
us → Locale
no setter