PhoneNumberMatcherImpl class final

Implemented types

Constructors

PhoneNumberMatcherImpl(PhoneNumberUtil util, String text, String country, Leniency leniency, Int64 maxTries)

Properties

current → PhoneNumberMatch
The current element.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkNumberGroupingIsValid(PhoneNumber number, String candidate, PhoneNumberUtil util, NumberGroupingChecker checker) → bool
moveNext() → bool
Advances the iterator to the next element of the iteration.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

punctuationLimit ↔ String
getter/setter pair

Static Methods

allNumberGroupsAreExactlyPresent(PhoneNumberUtil util, PhoneNumber number, StringBuffer normalizedCandidate, List<String> formattedNumberGroups) → bool
allNumberGroupsRemainGrouped(PhoneNumberUtil util, PhoneNumber number, StringBuffer normalizedCandidate, List<String> formattedNumberGroups) → bool
containsMoreThanOneSlashInNationalNumber(PhoneNumber number, String candidate) → bool
containsOnlyValidXChars(PhoneNumber number, String candidate, PhoneNumberUtil util) → bool
isLatinLetter(String character) → bool
isNationalPrefixPresentIfRequired(PhoneNumber number, PhoneNumberUtil util) → bool