PhonePrefixMap class

A utility that maps phone number prefixes to a description string, which maybe, for example, the geographical area the prefix covers.

Constructors

PhonePrefixMap(List<MapEntry<int, String>> _metadata)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

lookup({PhoneNumber? phoneNumber, int? number}) → String?
As per _lookup(long), but receives the number as a PhoneNumber instead of a long.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited